@@ -40,7 +40,8 @@ function(x, todtm = FALSE, re_control = list(wordLengths = c(1, 25))) {
 		triple_i <- unlist(lap_match)
 		triple_j <- rep.int(1: docnum, lengths(lap_match))
 		rm(lap_match)
-		triple_v <- unlist(mapply("[", lap, lapply_name))
+		triple_v <- unlist(mapply("[", lap, lapply_name, SIMPLIFY = FALSE))
+		## maybe matrix
 		## names to be NULL for package topicmodels
 		names(triple_v) <- NULL
 		m <- slam::simple_triplet_matrix(triple_i, triple_j, triple_v, nrow = length(lapply_unique), ncol = docnum, dimnames = list(Terms = lapply_unique, Docs = NULL))
